@@ -2,14 +2,9 @@ package internal
 
 import (
 	"fmt"
-	"regexp"
-	"runtime"
-	"runtime/debug"
-	"time"
 
 	log "github.com/sirupsen/logrus"
 	"github.com/walles/moor/v2/internal/linemetadata"
-	"github.com/walles/moor/v2/internal/reader"
 )
 
 // Scroll to the next search hit, while the user is typing the search string.
@@ -35,7 +30,7 @@ func (p *Pager) scrollToSearchHits() {
 		return
 	}
 
-	firstHitIndex := p.findFirstHit(*lineIndex, nil, false)
+	firstHitIndex := FindFirstHit(p.Reader(), *p.searchPattern, *lineIndex, nil, SearchDirectionForward)
 	if firstHitIndex == nil {
 		alreadyAtTheTop := (*lineIndex == linemetadata.Index{})
 		if alreadyAtTheTop {
@@ -44,7 +39,7 @@ func (p *Pager) scrollToSearchHits() {
 		}
 
 		// Try again from the top
-		firstHitIndex = p.findFirstHit(linemetadata.Index{}, lineIndex, false)
+		firstHitIndex = FindFirstHit(p.Reader(), *p.searchPattern, linemetadata.Index{}, lineIndex, SearchDirectionForward)
 	}
 	if firstHitIndex == nil {
 		// No match, give up
@@ -101,7 +96,7 @@ func (p *Pager) scrollToNextSearchHit() {
 		panic(fmt.Sprint("Unknown search mode when finding next: ", p.mode))
 	}
 
-	firstHitIndex := p.findFirstHit(firstSearchIndex, nil, false)
+	firstHitIndex := FindFirstHit(p.Reader(), *p.searchPattern, firstSearchIndex, nil, SearchDirectionForward)
 	if firstHitIndex == nil {
 		p.mode = PagerModeNotFound{pager: p}
 		return
@@ -140,7 +135,7 @@ func (p *Pager) scrollToSearchHitsBackwards() {
 	// Start at the top visible line
 	lineIndex := p.scrollPosition.lineIndex(p)
 
-	firstHitIndex := p.findFirstHit(*lineIndex, nil, true)
+	firstHitIndex := FindFirstHit(p.Reader(), *p.searchPattern, *lineIndex, nil, SearchDirectionBackward)
 	if firstHitIndex == nil {
 		lastReaderLineIndex := linemetadata.IndexFromLength(p.Reader().GetLineCount())
 		if lastReaderLineIndex == nil {
@@ -158,7 +153,7 @@ func (p *Pager) scrollToSearchHitsBackwards() {
 		}
 
 		// Try again from the bottom
-		firstHitIndex = p.findFirstHit(*lastReaderLineIndex, lineIndex, true)
+		firstHitIndex = FindFirstHit(p.Reader(), *p.searchPattern, *lastReaderLineIndex, lineIndex, SearchDirectionBackward)
 	}
 	if firstHitIndex == nil {
 		// No match, give up
@@ -218,7 +213,7 @@ func (p *Pager) scrollToPreviousSearchHit() {
 		panic(fmt.Sprint("Unknown search mode when finding previous: ", p.mode))
 	}
 
-	hitIndex := p.findFirstHit(firstSearchIndex, nil, true)
+	hitIndex := FindFirstHit(p.Reader(), *p.searchPattern, firstSearchIndex, nil, SearchDirectionBackward)
 	if hitIndex == nil {
 		p.mode = PagerModeNotFound{pager: p}
 		return
@@ -236,149 +231,6 @@ func (p *Pager) scrollToPreviousSearchHit() {
 	p.centerSearchHitsVertically()
 }
 
-// Search input lines. Not screen lines!
-//
-// The `beforePosition` parameter is exclusive, meaning that line will not be
-// searched.
-//
-// For the actual searching, this method will call _findFirstHit() in parallel
-// on multiple cores, to help large file search performance.
-func (p *Pager) findFirstHit(startPosition linemetadata.Index, beforePosition *linemetadata.Index, backwards bool) *linemetadata.Index {
-	// If the number of lines to search matches the number of cores (or more),
-	// divide the search into chunks. Otherwise use one chunk.
-	chunkCount := runtime.NumCPU()
-	var linesCount int
-	if backwards {
-		// If the startPosition is zero, that should make the count one
-		linesCount = startPosition.Index() + 1
-		if beforePosition != nil {
-			// Searching from 1 with before set to 0 should make the count 1
-			linesCount = startPosition.Index() - beforePosition.Index()
-		}
-	} else {
-		linesCount = p.Reader().GetLineCount() - startPosition.Index()
-		if beforePosition != nil {
-			// Searching from 1 with before set to 2 should make the count 1
-			linesCount = beforePosition.Index() - startPosition.Index()
-		}
-	}
-
-	if linesCount < chunkCount {
-		chunkCount = 1
-	}
-	chunkSize := linesCount / chunkCount
-
-	log.Debugf("Searching %d lines across %d cores with %d lines per core...", linesCount, chunkCount, chunkSize)
-	t0 := time.Now()
-	defer func() {
-		linesPerSecond := float64(linesCount) / time.Since(t0).Seconds()
-		linesPerSecondS := fmt.Sprintf("%.0f", linesPerSecond)
-		if linesPerSecond > 7_000_000.0 {
-			linesPerSecondS = fmt.Sprintf("%.0fM", linesPerSecond/1000_000.0)
-		} else if linesPerSecond > 7_000.0 {
-			linesPerSecondS = fmt.Sprintf("%.0fk", linesPerSecond/1000.0)
-		}
-
-		if linesCount > 0 {
-			log.Debugf("Searched %d lines in %s at %slines/s or %s/line",
-				linesCount,
-				time.Since(t0),
-				linesPerSecondS,
-				time.Since(t0)/time.Duration(linesCount))
-		} else {
-			log.Debugf("Searched %d lines in %s at %slines/s", linesCount, time.Since(t0), linesPerSecondS)
-		}
-	}()
-
-	// Each parallel search will start at one of these positions
-	searchStarts := make([]linemetadata.Index, chunkCount)
-	direction := 1
-	if backwards {
-		direction = -1
-	}
-	for i := 0; i < chunkCount; i++ {
-		searchStarts[i] = startPosition.NonWrappingAdd(i * direction * chunkSize)
-	}
-
-	// Make a results array, with one result per chunk
-	findings := make([]chan *linemetadata.Index, chunkCount)
-
-	// Search all chunks in parallel
-	for i, searchStart := range searchStarts {
-		findings[i] = make(chan *linemetadata.Index)
-
-		searchEndIndex := i + 1
-		var chunkBefore *linemetadata.Index
-		if searchEndIndex < len(searchStarts) {
-			chunkBefore = &searchStarts[searchEndIndex]
-		} else if beforePosition != nil {
-			chunkBefore = beforePosition
-		}
-
-		reader := p.Reader()
-		pattern := *p.searchPattern
-		go func(i int, searchStart linemetadata.Index, chunkBefore *linemetadata.Index) {
-			defer func() {
-				PanicHandler("findFirstHit()/chunkSearch", recover(), debug.Stack())
-			}()
-
-			findings[i] <- _findFirstHit(reader, searchStart, pattern, chunkBefore, backwards)
-		}(i, searchStart, chunkBefore)
-	}
-
-	// Return the first non-nil result
-	for _, finding := range findings {
-		result := <-finding
-		if result != nil {
-			return result
-		}
-	}
-
-	return nil
-}
-
-// NOTE: When we search, we do that by looping over the *input lines*, not the
-// screen lines. That's why startPosition is an Index rather than a
-// scrollPosition.
-//
-// The `beforePosition` parameter is exclusive, meaning that line will not be
-// searched.
-//
-// This method will run over multiple chunks of the input file in parallel to
-// help large file search performance.
-func _findFirstHit(reader reader.Reader, startPosition linemetadata.Index, pattern regexp.Regexp, beforePosition *linemetadata.Index, backwards bool) *linemetadata.Index {
-	searchPosition := startPosition
-	lineCache := searchLineCache{}
-	for {
-		line := lineCache.getLine(reader, searchPosition, backwards)
-		if line == nil {
-			// No match, give up
-			return nil
-		}
-
-		lineText := line.Plain()
-		if pattern.MatchString(lineText) {
-			return &searchPosition
-		}
-
-		if backwards {
-			if (searchPosition == linemetadata.Index{}) {
-				// Reached the top without any match, give up
-				return nil
-			}
-
-			searchPosition = searchPosition.NonWrappingAdd(-1)
-		} else {
-			searchPosition = searchPosition.NonWrappingAdd(1)
-		}
-
-		if beforePosition != nil && searchPosition == *beforePosition {
-			// No match, give up
-			return nil
-		}
-	}
-}
-
 // Return true if any search hit is currently visible on screen.
 //
 // A search hit is considered visible if the first character of the hit is
